@@ -2,6 +2,7 @@ import logging
 
 from pandas import DataFrame
 
+from pandas_orm.base.dataframe import is_base_dataframe
 from pandas_orm.sqlalchemy.execute_sql import DataFrameExecuteSql
 from pandas_orm.sqlalchemy.crud.naive_save_arguments import NativeModelSaveArguments
 
@@ -9,10 +10,10 @@ from pandas_orm.sqlalchemy.crud.naive_save_arguments import NativeModelSaveArgum
 class ModelDataFrameManager:
 
     @classmethod
-    def bulk_save(cls, records, model, engine_context_func, unique_fields=None,
+    def bulk_save(cls, dataframe, model, engine_context_func, unique_fields=None,
                    update_fields=None, returning_id=False):
         """
-        :param records: DataFrame or collection
+        :param dataframe: DataFrame or collection
         :param model: sqlalchemy.orm.declarative_base
         :param engine_context_func: engine_scope context
         :param unique_fields: List[field..]
@@ -20,7 +21,7 @@ class ModelDataFrameManager:
         :param returning_id: bool
         :return: saved DataFrame
         """
-        records = cls._prepare_records(records)
+        records = cls._prepare_records(dataframe)
         if records.empty:
             return records
         logging.info(f'Saving {records.shape[0]} {model.__name__} records')
@@ -43,16 +44,20 @@ class ModelDataFrameManager:
 
     @classmethod
     def _add_records_ids(cls, results, records):
-        new_records = records
         new_ids = results.fetchall()
-        if issubclass(records.__class__, DataFrame):
-            df_ids = DataFrame(new_ids, columns=['id'])
-            records['id'] = df_ids['id']
-            new_records = records.to_dict('records')
+        df_ids = DataFrame(new_ids, columns=['id'])
+        if is_base_dataframe(records):
+            records = cls.update_records_ids(df_ids, records)
         if isinstance(records, list):
-            [record.update({'id': new_id[0]}) for record, new_id in
-             zip(new_records, new_ids)]
-        return new_records
+            records = DataFrame(records)
+            records = cls.update_records_ids(df_ids, records)
+        return records
+
+    @classmethod
+    def update_records_ids(cls, df_ids, records):
+        records['id'] = df_ids['id']
+        records = records.to_dict('records')
+        return records
 
     @classmethod
     def _prepare_records(cls, records) -> DataFrame:
@@ -64,3 +69,22 @@ class ModelDataFrameManager:
         raise NotImplementedError(type(records))
 
 
+def bulk_save(dataframe, model, engine_context_func, unique_fields=None,
+              update_fields=None, returning_id=False):
+    """
+    :param dataframe: DataFrame or collection
+    :param model: sqlalchemy.orm.declarative_base
+    :param engine_context_func: engine_scope context
+    :param unique_fields: List[field..]
+    :param update_fields: List[field..]
+    :param returning_id: bool
+    :return: saved DataFrame
+    """
+    return ModelDataFrameManager.bulk_save(
+        dataframe=dataframe,
+        model=model,
+        engine_context_func=engine_context_func,
+        unique_fields=unique_fields,
+        update_fields=update_fields,
+        returning_id=returning_id,
+    )
